@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20260122.1320
-;; Package-Revision: d6126f95e019
+;; Package-Version: 20260123.1616
+;; Package-Revision: 595ca131343a
 ;; URL: https://github.com/jamescherti/kirigami.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "26.3"))
@@ -162,11 +162,27 @@ specific reason to disable these enhancements."
      :close      treesit-fold-close)
     ((hs-minor-mode)
      :open-all   hs-show-all
-     :close-all  hs-hide-all
-     :toggle     hs-toggle-hiding
-     :open       hs-show-block
-     :open-rec   nil
-     :close      hs-hide-block)
+     :close-all  ,(lambda ()
+                    ;; Restore the column because `hs-hide-all' may move
+                    ;; point backward
+                    ;; TODO: Emacs patch?
+                    (kirigami--call-preserve-column 'hs-hide-all))
+     :toggle     ,(lambda ()
+                    ;; Restore the column because `hs-toggle-hiding' may move
+                    ;; point backward
+                    ;; TODO: Emacs patch?
+                    (kirigami--call-preserve-column 'hs-toggle-hiding))
+     :open      ,(lambda ()
+                   ;; Restore the column because `hs-show-block' may move point
+                   ;; backward
+                   ;; TODO: Emacs patch?
+                   (kirigami--call-preserve-column 'hs-show-block))
+     :open-rec  nil
+     :close     ,(lambda ()
+                   ;; Restore the column because `hs-hide-block' may move point
+                   ;; backward
+                   ;; TODO: Emacs patch?
+                   (kirigami--call-preserve-column 'hs-hide-block)))
     ((hide-ifdef-mode)
      :open-all   show-ifdefs
      :close-all  hide-ifdefs
@@ -293,6 +309,17 @@ would ignore `:close-all' actions and invoke the provided functions on
 ;;        (kirigami--message
 ;;         (concat ,(car args)) ,@(cdr args)))))
 
+(defun kirigami--call-preserve-column (fn)
+  "Call FN and restore point to the original column when possible."
+  (let ((column (current-column)))
+    (when (fboundp fn)
+      (funcall fn)
+      (let ((line-size (- (line-end-position)
+                          (line-beginning-position))))
+        (move-to-column (if (< column line-size)
+                            column
+                          line-size))))))
+
 (defun kirigami--mode-p (modes)
   "Check if any symbol in MODES matches the current buffer's modes."
   (unless (eq modes '())
